@@ -2,7 +2,6 @@
 test_that("Reload", {
     skip_on_cran()
     eplusr_option(verbose_info = FALSE)
-    if (!is_avail_eplus(8.8)) install_eplus(8.8)
 
     # default
     expect_equal(reload(1L), 1L)
@@ -83,8 +82,8 @@ test_that("Reload", {
     expect_idf_reloaded(get_priv_env(par)$m_seed)
     lapply(get_priv_env(grp)$m_idfs, expect_idf_reloaded)
     lapply(get_priv_env(par)$m_idfs, expect_idf_reloaded)
-    expect_true(data.table::truelength(get_priv_env(grp)$m_job) > 0L)
-    expect_true(data.table::truelength(get_priv_env(par)$m_job) > 0L)
+    expect_true(data.table::truelength(get_priv_env(grp)$m_job$jobs) > 0L)
+    expect_true(data.table::truelength(get_priv_env(par)$m_job$jobs) > 0L)
 
     expect_true(job$status()$successful)
     expect_true(grp$status()$successful)
